/* 

This file is for keeping the important Gallup variables, merging them with 
World Bank macro variables, and preparing them for a happiness economics analysis.

Last modified by: Hamed
Las modified on: 26/02/2021 6.28pm

Notes:

*/

clear all
cd "C:\Users\rmac024\Desktop\Hamed_2022\"

    *********************************************************
    *														*
    *	Note: change the working directory to yours		  	*
    *														*
    *********************************************************

* set maxvar 5000 //just in case we use the "Small" version of STATA later on

*****************************************************
* removing unneccesary variables from Gallup dataset / adding the required variables and dummies

use "The_Gallup_032720.dta"
set more off
/* Changes in the 2020 Gallup variables (see the country name changes in the WB section of this code)
	INC_001 to INC_007 are replaced with INCOME_X variables. For instance:
	INCOME_1 is Annual Household Income in Local Currency
	INCOME_5 is Per Capita Income Quintiles (It was previousely called INC_004)
	Other changes: 
	  wp16 >> WP16
	  wp18 >> WP18
	  wp3117 >> WP3117.
*/

* Descriptive statistics for the ladder question
// sum WP16, d // Life Today
// sum WP18, d // Life in Five Years
// sum YEAR_CALENDAR, d


* dropping the unneccesary variables
keep countrynew YEAR_CALENDAR WP5 REG_GLOBAL REG2_GLOBAL YEAR_WAVE FIELD_DATE country WP4 INCOME_7 INCOME_5 INCOME_4 INCOME_3 income_2 INCOME_1 WP10248 WP108 WP109 WP110 WP112 WP113 WP117 WP16 WP18 WP22 WP23 WP2319 WP27 WP30 WP31 WP3117 wp52 WP60 WP61 WP63 WP65 WP67 WP68 WP6878 WP69 WP70 WP71 WP74 WP83 WP85 WP86 WP88 WP89 WP93 INDEX_CE INDEX_PX INDEX_NX INDEX_LE INDEX_LO INDEX_JC INDEX_CA INDEX_OT WP1219 WP1220 WP1223 WP1225 WP1230 EMP_2010 WP5378 WP12339 WP4656 WP10222 WP4692 WP1363 WP145 WP80 WP146 WP3111 
order countrynew WP5 YEAR_CALENDAR
save "HappinessPanelData2021", replace

* creating dummies
generate int Sadness:yes = (WP70==1)
// otherwise no Sadness

generate int Happiness:yes = (WP6878==1)
// otherwise no Happiness

generate int Smile:yes = (WP63==1)
// otherwise no Smile

generate int Enjoyment:yes = (WP67==1)
// otherwise no Enjoyment

generate int Pain:yes = (WP68==1)
// otherwise no Pain

generate int Worry:yes = (WP69==1)
// otherwise no Worry

generate int Stress:yes = (WP71==1)
// otherwise no Stress

generate int Anger:yes = (WP74==1)
// otherwise no Anger

generate int Health:HealthySatisfied = (WP22==1)
// otherwise Health dissatisfied

generate int gender:female = (WP1219==2)
// otherwise male, or similarly
generate int female = (WP1219==2), after(gender)
generate int male = (WP1219==1), after(female)

generate int selfemployed:selfemployed = (EMP_2010==2)
generate int employed:employed = (EMP_2010==1 | EMP_2010==3 | EMP_2010==5)
generate int unemployed:unemployed = (EMP_2010==4)
generate int outofworkforce:outofworkforce = (EMP_2010==6)

generate int young = (WP1220<=35)
generate int middleaged = (WP1220>=36 & WP1220<=54)
generate int elderly = (WP1220>=55)
generate int age = WP1220

generate int married = (WP1223==2 | WP1223==8)
generate int single = (WP1223==1)
generate int divorced = (WP1223==3 | WP1223==4)
generate int widowed = (WP1223==5)

generate int  nochild = WP1230==0
generate int  onechild = WP1230==1
generate int  twochildren = WP1230==2
generate int  threepluschildren = WP1230>=3

generate int poor = (INCOME_5==1)
generate int lowerincome = (INCOME_5==2)
generate int middleincome = (INCOME_5==3)
generate int higherincome = (INCOME_5==4)
generate int rich = (INCOME_5==5)

generate int elementaryschool = (WP3117==1)
generate int secondaryschool = (WP3117==2)
generate int tertiaryschool = (WP3117==3)

generate int REGtemp:AsiaNoPacific = (REG2_GLOBAL==3 & WP5!=47 & WP5!=55)
generate int REGtemp1:NorthAfrica = (WP5==2 | WP5==141 | WP5==190 | WP5==3 | WP5==84) // Egypt 2 Morocco 141 Algeria 190 Tunisia 3 Libya 84
generate int REGtemp2:MiddleEastWithoutNorthAfrica = (REG2_GLOBAL==5 & REGtemp1!=1)
generate int REGtemp3:FSSEastEurope = (WP5==71 | WP5==75 | WP5==138 | WP5==143 | WP5==119 | WP5==76 | WP5==72 | WP5==77) //Belarus 71 Moldova 75 Latvia 138 Lithuania 143 Estonia 119 Russia 76 Georgia 72 Ukraine 77
generate int REGtemp4:FSSCentralAsia = (REG2_GLOBAL==2 & REGtemp3!=1)

generate int Asia = (REGtemp==1 | REGtemp2==1 | REGtemp4==1)
generate int Europe = (REG2_GLOBAL==1 | REGtemp3==1)
generate int Americas = (REG2_GLOBAL==4)
generate int Africa = (REG2_GLOBAL==6 | REGtemp1==1)
generate int Pacific = (REG_GLOBAL==5)

generate int AUS:Australia = (WP5==47)
generate int NZ:NewZealand = (WP5==55)
generate int US:UnitedStates = (WP5==1)
generate int Canada:Canada = (WP5==46)
generate int India = (WP5==31)
generate int China = (WP5==30)

generate int NorthAmerica:USandCanada = (WP5==1 | WP5==46)
generate int SouthAmerica:NotUSandCanada = (REG2_GLOBAL==4 & NorthAmerica!=1)
generate int FormerUSSR = (REG2_GLOBAL==2)
generate int MiddleEast = (REGtemp2==1 | WP5==2)
generate int MENA = (REG2_GLOBAL==5)
generate int EuropeanUnion = (REG_GLOBAL==1)
generate int AusNZ:AustraliaandNewZealand = (REG_GLOBAL==5)
generate int SouthEastAsia = (REG_GLOBAL==6)
generate int SouthAsia = (REG_GLOBAL==7)
generate int EasternEurope = (REGtemp3==1)

generate int BeforeGFC:BeforeGlobalFinancialCrisis = (YEAR_CALENDAR<=2007)
generate int GFC:GlobalFinancialCrisis = (YEAR_CALENDAR==2008 | YEAR_CALENDAR==2009)
generate int AfterGFC:AfterGlobalFinancialCrisis = (YEAR_CALENDAR>=2010 & YEAR_CALENDAR<=2017)
generate int Recent:LastThreeYears = (YEAR_CALENDAR>=2018)

generate int AsiaCrisis = (Asia==1 & YEAR_CALENDAR==2009)
generate int EuropeCrisis = (Europe==1 & YEAR_CALENDAR==2009)
generate int AmericasCrisis = (Americas==1 & YEAR_CALENDAR==2009)
generate int AfricaCrisis = (Africa==1 & YEAR_CALENDAR==2009)
generate int PacificCrisis = (Pacific==1 & YEAR_CALENDAR==2009)

local i = 1
while `i' <= 207 { // country dummies
generate int c`i' = (WP5==`i')
local i = `i' + 1
}

local i = 1
while `i' <= 207 { // country trend dummies
generate int ct`i' = (WP5==`i')
replace ct`i' = YEAR_CALENDAR if ct`i'>0
local i = `i' + 1
}

local i = 2005
while `i' <= 2020 { // year dummies
generate int year`i' = (YEAR_CALENDAR==`i')
local i = `i' + 1
}
generate int Notcrisisext:not2008to09 = (YEAR_CALENDAR!=2008 & YEAR_CALENDAR!=2009)
generate int Notcrisis:not2009 = (YEAR_CALENDAR!=2009)

generate int year2005to07 = (YEAR_CALENDAR==2005 | YEAR_CALENDAR==2006 | YEAR_CALENDAR==2007)
generate int year2008to10 = (YEAR_CALENDAR==2008 | YEAR_CALENDAR==2009 | YEAR_CALENDAR==2010)
generate int year2011to13 = (YEAR_CALENDAR==2011 | YEAR_CALENDAR==2012 | YEAR_CALENDAR==2013)
generate int year2014to16 = (YEAR_CALENDAR==2014 | YEAR_CALENDAR==2015 | YEAR_CALENDAR==2016)
generate int year2017to19 = (YEAR_CALENDAR==2017 | YEAR_CALENDAR==2018 | YEAR_CALENDAR==2019)
// Variable year2020 is already defined.

* removing "Don't know" and "no response" and matching missing observations
replace WP10248 = . if WP10248==3 | WP10248==4
replace WP108 = . if WP108==3 | WP108==4
replace WP109 = . if WP109==3 | WP109==4
replace WP110 = . if WP110==3 | WP110==4
replace WP112 = . if WP112==3 | WP112==4
replace WP113 = . if WP113==3 | WP113==4
replace WP117 = . if WP117==3 | WP117==4
replace WP16 = . if WP16==98 | WP16==99
replace WP18 = . if WP18==98 | WP18==99
replace gender = . if WP1219==.
replace female = . if WP1219==.
replace male = . if WP1219==.
replace Health = . if WP22==3 | WP22==4 | WP22==.
replace WP23 = . if WP23==3 | WP23==4
replace WP2319 = . if WP2319==5 | WP2319==6
replace WP27 = . if WP27==3 | WP27==4
replace WP30 = . if WP30==3 | WP30==4
replace WP31 = . if WP31==4 | WP31==5
replace wp52 = . if wp52==3 | wp52==4
replace WP60 = . if WP60==3 | WP60==4
replace WP61 = . if WP61==3 | WP61==4
replace Smile = . if WP63==3 | WP63==4 | WP63==.
replace WP65 = . if WP65==3 | WP65==4
replace Enjoyment = . if WP67==3 | WP67==4 | WP67==.
replace Pain = . if WP68==3 | WP68==4 | WP68==.
replace Happiness = . if WP6878==3 | WP6878==4 | WP6878==.
replace Worry = . if WP69==3 | WP69==4 | WP69==.
replace Sadness = . if WP70==3 | WP70==4 | WP70==.
replace Stress = . if WP71==3 | WP71==4 | WP71==.
replace Anger = . if WP74==3 | WP74==4 | WP74==.
replace WP83 = . if WP83==3 | WP83==4
replace WP85 = . if WP85==3 | WP85==4
replace WP86 = . if WP86==3 | WP86==4
replace WP88 = . if WP88==3 | WP88==4
replace WP89 = . if WP89==3 | WP89==4
replace WP93 = . if WP93==3 | WP93==4
replace WP1225 = . if WP1225==13 | WP1225==14
replace WP1230 = . if WP1230==98 | WP1230==99
replace nochild = . if WP1230==98 | WP1230==99
replace onechild = . if WP1230==98 | WP1230==99
replace twochildren = . if WP1230==98 | WP1230==99
replace threepluschildren = . if WP1230==98 | WP1230==99
// how about 97+ children? or maybe all over 50? Shall we do this????????
replace WP1230 = 40 if WP1230>=40
replace WP5378 = . if WP5378==3 | WP5378==4
replace WP12339 = . if WP12339==98 | WP12339==99
replace WP4656 = . if WP4656==98 | WP4656==99
replace WP10222 = . if WP10222==4 | WP10222==5
replace WP4692 = . if WP4692==5 | WP4692==6
replace WP1363 = . if WP1363==3 | WP1363==4
replace WP145 = . if WP145==3 | WP145==4
replace WP80 = . if WP80==98 | WP80==99
// how abuot 97 (Less than 1 hour free time in a day)? Shall we do this????????
replace WP80 = 0.5 if WP80==97
replace WP146 = . if WP146==3 | WP146==4
replace WP3111 = . if WP3111==4 | WP3111==5
// no nonsense label for Indexes, EMP_2010, WP1219, INCOME_5

replace selfemployed = . if  EMP_2010==.
replace employed = . if  EMP_2010==.
replace unemployed = . if  EMP_2010==.
replace outofworkforce = . if  EMP_2010==.

replace young = . if  WP1220==. | WP1220==100
replace middleaged = . if  WP1220==. | WP1220==100
replace elderly = . if  WP1220==. | WP1220==100
replace age = . if  WP1220==. | WP1220==100
// how about age 99+ ????????

replace married = . if WP1223==6 | WP1223==7 | WP1223==.
replace single = . if WP1223==6 | WP1223==7 | WP1223==.
replace divorced = . if WP1223==6 | WP1223==7 | WP1223==.
replace widowed = . if WP1223==6 | WP1223==7 | WP1223==.

replace poor = . if INCOME_5==.
replace lowerincome = . if INCOME_5==.
replace middleincome = . if INCOME_5==.
replace higherincome = . if INCOME_5==.
replace rich = . if INCOME_5==.

replace elementaryschool = . if WP3117==4 | WP3117==5 | WP3117==.
replace secondaryschool = . if WP3117==4 | WP3117==5 | WP3117==.
replace tertiaryschool = . if WP3117==4 | WP3117==5 | WP3117==.

drop REGtemp REGtemp1 REGtemp2 REGtemp3 REGtemp4

/*
******* The collapse command if we do not want to use some of the above dummies
collapse (mean) wp5 REG_GLOBAL REG2_GLOBAL WP4 FIELD_DATE YEAR_WAVE INCOME_5 WP10248 WP108 WP109 WP110 WP112 WP113 WP117 WP16 WP18 WP22 WP23 WP2319 WP27 WP30 WP31 WP3117 wp52 WP60 WP61 WP63 WP65 WP67 WP68 WP6878 WP69 WP70 WP71 WP74 WP83 WP85 WP86 WP88 WP89 WP93 INDEX_FW INDEX_PW INDEX_EW INDEX_SW INDEX_CE INDEX_PX INDEX_NX INDEX_LE INDEX_LO INDEX_JC INDEX_CA INDEX_OT WP1219 WP1220 WP1223 WP1225 WP1230 EMP_2010 WP5378 WP12339 WP4656 WP10222 WP4692 WP1363 WP145 WP80 WP146 WP3111, by(countrynew YEAR_CALENDAR)
*/

//br

save "HappinessPanelData2021", replace


*****************************************************
* Importing the WB data and amending the variable names, country names and so on in WB data file

clear all
set more off

* Importing the csv file 
import delimited "WB happiness data - Feb 2021.csv", varnames(1) asdouble

// population values

* Matching and simplifying the variable names
rename ( ïcountryname countrycode time timecode co2emissionskgperpppofgdpenatmco intentionalhomicidesper100000peo generalgovernmentfinalconsumptio communityhealthworkersper1000peo schoolenrollmenttertiarygrossset schoolenrollmentsecondarygrossse unemploymenttotaloftotallaborfor unemploymentyouthtotaloftotallab grosscapitalformationofgdpnegdit grossdomesticsavingsofgdpnygdsto governmentexpenditureperstudentt governmentexpenditureperstudents governmentexpenditureoneducation lifeexpectancyatbirthtotalyearss agedependencyratioyoungofworking gdppercapitapppconstant2017inter gdppercapitaconstant2010usnygdpp foreigndirectinvestmentnetinflow gdppercapitagrowthannualnygdppca marketcapitalizationoflisteddome tradeofgdpnetrdgnfszs inflationconsumerpricesannualfpc netmigrationsmpopnetm strengthoflegalrightsindex0weakt mortalityrateunder5per1000livebi giniindexworldbankestimatesipovg netprimaryincomenetincomefromabr populationgrowthannualsppopgrow secondaryeducationteacherssesect lendinginterestratefrinrlend populationtotalsppoptotl) ( countrynew countrycode YEAR_CALENDAR timecode co2emissions homicides govfinalconsumption communityhealthworkers schoolenrollmenttertiary schoolenrollmentsecondary unemployment unemploymentyouth grosscapitalformationofgdpnegdit grossdomesticsavings governmentexpenditureperstudentt governmentexpenditureperstudents governmentexpenditureoneducation lifeexpectancyatbirthtotalyears agedependencyratio gdppercapitapppconstant2017inter gdppercapitaconstant2010 foreigndirectinvestmentnetinflow gdppcgrowth marketcapitalization openness inflation netmigration strengthoflegalrights mortalityrateunder5 gini netincomefromabroadconstantlcu populationgrowth secondaryeducationteachers lendinginterestrate population)

* Dropping explanations at the end
drop if countrycode==""

* Changing selected variable types to double
destring ( co2emissions homicides govfinalconsumption communityhealthworkers schoolenrollmenttertiary schoolenrollmentsecondary unemployment unemploymentyouth grosscapitalformationofgdpnegdit grossdomesticsavings governmentexpenditureperstudentt governmentexpenditureperstudents governmentexpenditureoneducation lifeexpectancyatbirthtotalyears agedependencyratio gdppercapitaconstant2010 foreigndirectinvestmentnetinflow gdppcgrowth marketcapitalization openness inflation netmigration strengthoflegalrights mortalityrateunder5 gini netincomefromabroadconstantlcu populationgrowth secondaryeducationteachers lendinginterestrate population), replace force
generate float netimmigration = netmigration/population*100

//drop netimmigration
//generate int openness = opennessnum

*************************************************************************************
* Changing country names to match Gallup
replace countrynew = "Congo (Kinshasa)" if countrynew=="Congo, Dem. Rep."
replace countrynew = "Congo Brazzaville" if countrynew=="Congo, Rep."
replace countrynew = "Egypt" if countrynew=="Egypt, Arab Rep."
replace countrynew = "Hong Kong" if countrynew=="Hong Kong SAR, China"
replace countrynew = "Iran" if countrynew=="Iran, Islamic Rep."
replace countrynew = "Ivory Coast" if countrynew=="Cote d'Ivoire"
replace countrynew = "Kyrgyzstan" if countrynew=="Kyrgyz Republic"
replace countrynew = "Laos" if countrynew=="Lao PDR"
replace countrynew = "Palestinian Territories" if countrynew=="West Bank and Gaza"
replace countrynew = "Russia" if countrynew=="Russian Federation"
replace countrynew = "Slovakia" if countrynew=="Slovak Republic"
replace countrynew = "South Korea" if countrynew=="Korea, Rep."
replace countrynew = "Syria" if countrynew=="Syrian Arab Republic"
replace countrynew = "Venezuela" if countrynew=="Venezuela, RB"
replace countrynew = "Yemen" if countrynew=="Yemen, Rep."
replace countrynew = "The Gambia" if countrynew=="Gambia, The"

* Minor changes in country names (Gallup include these country names but does not have data for them)
replace countrynew = "Antigua & Barbuda" if countrynew=="Antigua and Barbuda" 
replace countrynew = "Bahamas" if countrynew=="Bahamas, The"
replace countrynew = "North Korea" if countrynew=="Korea, Dem. People's Rep."
replace countrynew = "Brunei" if countrynew=="Brunei Darussalam"
replace countrynew = "Cape Verde" if countrynew=="Cabo Verde"
replace countrynew = "Micronesia" if countrynew=="Micronesia, Fed. Sts." 
replace countrynew = "Sao Tome & Principe" if countrynew=="Sao Tome and Principe"
replace countrynew = "St. Kitts & Nevis" if countrynew=="St. Kitts and Nevis"
replace countrynew = "Saint Lucia" if countrynew=="St. Lucia"
replace countrynew = "St. Vincent & Grenadines" if countrynew=="St. Vincent and the Grenadines" 

* Countries reported in Gallup but not available in the WB dataset
* there is no match for the Gallup's "Somaliland". This is a self-declared state internationally recognized as an autonomous region of Somalia. 
* there is no match for the Gallup's "North Cyprus". This state is recognised only by Turkey. WB only reports the "Cyprus" data.)
* there is no match for the Gallup's "Nagorno Karabakh", the unrecognized state established within Azerbaijan.
* there is no match for the Gallup's "Taiwan", which is no longer a member of the UN.

* dropping the countries available in the WB dataset but not in Gallup:
drop if countrynew=="American Samoa" | countrynew=="Aruba" | countrynew=="Bermuda" | countrynew=="Cayman Islands" | countrynew=="Channel Islands" | countrynew=="Curacao" | countrynew=="Dominica" | countrynew=="Faeroe Islands" | countrynew=="French Polynesia" | countrynew=="Greenland" | countrynew=="Guam" | countrynew=="Isle of Man" | countrynew=="Liechtenstein" | countrynew=="Macao SAR, China" | countrynew=="New Caledonia" | countrynew=="Northern Mariana Islands" | countrynew=="Sint Maarten (Dutch part)" | countrynew=="Turks and Caicos Islands" | countrynew=="Virgin Islands (U.S.)"

* create lead/lag variables
sort countrynew YEAR_CALENDAR
  //population
  . by countrynew: gen double populationLag1 = population[_n-1]
  . by countrynew: gen double populationLag2 = population[_n-2]
  . by countrynew: gen double populationLag3 = population[_n-3]
  . by countrynew: gen double populationLead1 = population[_n+1]
  . by countrynew: gen double populationLead2 = population[_n+2]
  . by countrynew: gen double populationLead3 = population[_n+3]
  
  //gdp per capita
  order gdppercapitaconstant2010, after(populationLead3)
  . by countrynew: gen double gdppercapitaconstant2010Lag1 = gdppercapitaconstant2010[_n-1]
  . by countrynew: gen double gdppercapitaconstant2010Lag2 = gdppercapitaconstant2010[_n-2]
  . by countrynew: gen double gdppercapitaconstant2010Lag3 = gdppercapitaconstant2010[_n-3]
  . by countrynew: gen double gdppercapitaconstant2010Lead1 = gdppercapitaconstant2010[_n+1]
  . by countrynew: gen double gdppercapitaconstant2010Lead2 = gdppercapitaconstant2010[_n+2]
  . by countrynew: gen double gdppercapitaconstant2010Lead3 = gdppercapitaconstant2010[_n+3]  
  
    //unemployment
  order unemployment, after(gdppercapitaconstant2010Lead3)
  . by countrynew: gen double unemploymentLag1 = unemployment[_n-1]
  . by countrynew: gen double unemploymentLag2 = unemployment[_n-2]
  . by countrynew: gen double unemploymentLag3 = unemployment[_n-3]
  . by countrynew: gen double unemploymentLead1 = unemployment[_n+1]
  . by countrynew: gen double unemploymentLead2 = unemployment[_n+2]
  . by countrynew: gen double unemploymentLead3 = unemployment[_n+3]
  
  //inflation
  order inflation, after(unemploymentLead3)
  . by countrynew: gen double inflationLag1 = inflation[_n-1]
  . by countrynew: gen double inflationLag2 = inflation[_n-2]
  . by countrynew: gen double inflationLag3 = inflation[_n-3]
  . by countrynew: gen double inflationLead1 = inflation[_n+1]
  . by countrynew: gen double inflationLead2 = inflation[_n+2]
  . by countrynew: gen double inflationLead3 = inflation[_n+3]
  
  //government consumption as a fraction of GDP
  order govfinalconsumption, after(inflationLead3)
  . by countrynew: gen double govfinalconsumptionLag1 = govfinalconsumption[_n-1]
  . by countrynew: gen double govfinalconsumptionLag2 = govfinalconsumption[_n-2]
  . by countrynew: gen double govfinalconsumptionLag3 = govfinalconsumption[_n-3]
  . by countrynew: gen double govfinalconsumptionLead1 = govfinalconsumption[_n+1]
  . by countrynew: gen double govfinalconsumptionLead2 = govfinalconsumption[_n+2]
  . by countrynew: gen double govfinalconsumptionLead3 = govfinalconsumption[_n+3]  
  
drop if YEAR_CALENDAR < 2005
  		
save "WB happiness data 2021", replace


*************************************************************************************
*** Merging the datasets
clear all
set more off

use "HappinessPanelData2021.dta", clear

merge m:m countrynew YEAR_CALENDAR using "WB happiness data 2021"

drop if _merge==2

* there is no "Nagorno Karabakh" and "North Cyprus" at WB data. In GALLUP, the former is only available in 2013, and the latter is only available in 2012 and 2013.

drop _merge

// describe

* defining panel. In case we use collapse command
//tsset, clear
//tsset wp5 YEAR_CALENDAR

save "HappinessPanelData2021", replace

* Saving all the labels in a do file
label save using "ALLlabels", replace

generate int age2 = age^2

rename WP5 country


************************************************************************************************************************
gen Ladder=0
replace Ladder=1 if WP16>=5 & WP16<=10
replace Ladder=. if WP16==.

replace unemployment=unemployment/100
replace inflation=inflation/100


*************************************************************************************************************************
dprobit Ladder unemployment inflation unemployed male age lowerincome middleincome higherincome rich secondaryschool tertiaryschool married divorced widowed onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Ladder unemployment inflation c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

**********************************************************
******************** TABLE 1 *****************************
**********************************************************
reg WP16       unemployment inflation                 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 if unemployment<. & inflation<., cluster(country)

reg WP16       unemployment inflation                 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

reg WP16       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

oprobit WP16   unemployment inflation   c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 if unemployment<. & inflation<., cluster(country)

oprobit WP16   unemployment inflation   c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

oprobit WP16       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

**************************************************************
**************** TABLE 2 *************************************
**************************************************************

dprobit Sadness    unemployment inflation c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Sadness     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Sadness                     unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

********************************************************************
dprobit Pain    unemployment inflation c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Pain     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Pain                     unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

***********************************************************************
************************************ TABLE 3 **************************
***********************************************************************

dprobit Enjoyment    unemployment inflation c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Enjoyment   unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Enjoyment                     unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

*********************************************************************
dprobit Smile    unemployment inflation c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Smile   unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)

dprobit Smile          unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if unemployment<. & inflation<., cluster(country)


***************************************************************************************
************************* HIGH / LOW INFLATION ****************************************
***************************************************************************************
******************************** TABLE 5 **********************************************
***************************************************************************************

********* LADDER OF LIFE **************
reg WP16       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation>0.05 & inflation<., cluster(country)

keep if WP16<. & unemployment<. & inflation<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & inflation>0.05 & inflation<.
collapse (mean) WP16 unemployment inflation unemployed male age lowerincome middleincome higherincome rich secondaryschool tertiaryschool married divorced widowed onechild twochildren threepluschildren, by(country YEAR_CALENDAR)

reg WP16       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation<=0.05 & inflation<., cluster(country)

keep if WP16<. & unemployment<. & inflation<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & inflation<=0.05 & inflation<.
collapse (mean) WP16 unemployment inflation unemployed male age lowerincome middleincome higherincome rich secondaryschool tertiaryschool married divorced widowed onechild twochildren threepluschildren, by(country YEAR_CALENDAR)


***************** SADNESS ***********************
dprobit Sadness       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation>=0.05 & inflation<., cluster(country)

keep if Sadness<. & unemployment<. & inflation<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & inflation<=0.05 & inflation<.
collapse (mean) Sadness unemployment inflation unemployed male age lowerincome middleincome higherincome rich secondaryschool tertiaryschool married divorced widowed onechild twochildren threepluschildren, by(country YEAR_CALENDAR)

dprobit Sadness       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation<0.05 & inflation<., cluster(country)

keep if Sadness<. & unemployment<. & inflation<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & inflation>0.05 & inflation<.
collapse (mean) Sadness unemployment inflation unemployed male age lowerincome middleincome higherincome rich secondaryschool tertiaryschool married divorced widowed onechild twochildren threepluschildren, by(country YEAR_CALENDAR)

***************** PAIN *******************
dprobit Pain       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation>=0.05 & inflation<., cluster(country)

dprobit Pain       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation<0.05 & inflation<., cluster(country)

***************** ENJOYMENT *******************
dprobit Enjoyment       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation>=0.05 & inflation<., cluster(country)

dprobit Enjoyment       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation<0.05 & inflation<., cluster(country)

***************** SMILE *******************
dprobit Smile       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation>=0.05 & inflation<., cluster(country)

dprobit Smile       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation<0.05 & inflation<., cluster(country)

dprobit Smile       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if inflation<0.05 & inflation<., cluster(country)

************************* REGIONS ****************************************
******************* Asia, Europe, Americas, Africa, Pacific **************
************************ TABLE 6 *****************************************
**************************************************************************

*** South America ***

reg WP16        unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if SouthAmerica==1, cluster(country)

dprobit Sadness  unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if SouthAmerica==1, cluster(country)

dprobit Pain     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if SouthAmerica==1, cluster(country)

dprobit Enjoyment unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if SouthAmerica==1, cluster(country)

dprobit Smile     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if SouthAmerica==1, cluster(country)

*** Europe ***

reg WP16       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if Europe==1, cluster(country)

dprobit Sadness  unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if Europe==1, cluster(country)

dprobit Pain     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if Europe==1, cluster(country)

dprobit Enjoyment unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if Europe==1, cluster(country)

dprobit Smile     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 if Europe==1, cluster(country)

keep if WP16<. & unemployment<. & inflation<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & SouthAmerica==1
keep if WP16<. & unemployment<. & inflation<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & Europe==1

collapse (mean) WP16 unemployment inflation unemployed male age lowerincome middleincome higherincome rich secondaryschool tertiaryschool married divorced widowed onechild twochildren threepluschildren, by(country YEAR_CALENDAR)


******************************************************************************************
********************************** HIGH & LOW GDP ****************************************
******************************************************************************************

summ gdppercapitaconstant2010 if WP16<. & unemployed<. & age<. & male<. & lowerincome<. & middleincome<. & higherincome<. & rich<. & married<. & divorced<. & widowed<. & secondaryschool<. & tertiaryschool<. & onechild<. & twochildren<. & threepluschildren<. & unemployment<. & inflation<.

reg WP16        unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010<=18941 & gdppercapitaconstant2010<., cluster(country)

reg WP16        unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010>18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Sadness  unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010<=18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Sadness  unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010>18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Pain     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010<=18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Pain     unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010>18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Enjoyment unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010<=18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Enjoyment  unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010>18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Smile      unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010<=18941 & gdppercapitaconstant2010<., cluster(country)

dprobit Smile       unemployment inflation unemployed age male lowerincome middleincome higherincome rich married divorced widowed secondaryschool tertiaryschool onechild twochildren threepluschildren c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 c16 c17 c18 c19 c20 c21 c22 c23 c24 c25 c26 c27 c28 c29 c30 c31 c32 c33 c34 c35 c36 c37 c38 c39 c40 c41 c42 c43 c44 c45 c46 c47 c48 c49 c50 /*
*/ c51 c52 c53 c54 c55 c56 c57 c58 c59 c60 c61 c62 c63 c64 c65 c66 c67 c68 c69 c70 c71 c72 c73 c74 c75 c76 c77 c78 c79 c80 c81 c82 c83 c84 c85 c86 c87 c88 c89 c90 c91 c92 c93 c94 c95 c96 c97 c98 c99 c100 /*
*/ c101 c102 c103 c104 c105 c106 c107 c108 c109 c110 c111 c112 c113 c114 c115 c116 c117 c118 c119 c120 c121 c122 c123 c124 c125 c126 c127 c128 c129 c130 c131 c132 c133 c134 c135 c136 c137 c138 c139 c140 c141 c142 c143 c144 c145 c146 c147 c148 c149 c150 /*
*/ c151 c152 c153 c154 c155 c156 c157 c158 c159 c160 c161 c162 c163 c164 c165 c166 c167 c168 c169 c170 c171 c172 c173 c174 c175 c176 c177 c178 c179 c180 c181 c182 c183 c184 c185 c186 c187 c188 c189 c190 c191 c192 c193 c194 c195 c196 c197 c198 c199 c200 c201 c202 c203 c204 c205 c206 c207 year2005 year2006 year2007 year2008 year2009 year2010 year2011 year2012 year2013 year2014 year2015 year2016 year2017 year2018 year2019 year2020 /*
*/ if gdppercapitaconstant2010>18941 & gdppercapitaconstant2010<., cluster(country)

